const got = require('@/utils/got');
const cheerio = require('cheerio');
const { parseDate } = require('@/utils/parse-date');

module.exports = async (ctx) => {
    const category = ctx.params.category ?? '';
    const sort = ctx.params.sort ?? '';

    const rootUrl = 'https://2047.name';
    const currentUrl = `${rootUrl}${category ? `/c/${category}` : ''}${sort ? `?sortby=${sort}` : ''}`;

    const response = await got({
        method: 'get',
        url: currentUrl,
    });

    const $ = cheerio.load(response.data);

    const list = $('.threadlist_title')
        .slice(0, ctx.query.limit ? parseInt(ctx.query.limit) : 50)
        .map((_, item) => {
            item = $(item);

            return {
                title: item.text(),
                link: `${rootUrl}${item.attr('href')}`,
            };
        })
        .get();

    const items = await Promise.all(
        list.map((item) =>
            ctx.cache.tryGet(item.link, async () => {
                const detailResponse = await got({
                    method: 'get',
                    url: item.link,
                });

                const content = cheerio.load(detailResponse.data);

                item.description = content('.post_content').eq(0).html();
                item.author = content('meta[property="og:article:author"]').attr('content');
                item.pubDate = parseDate(content('meta[property="og:article:published_time"]').attr('content'));

                return item;
            })
        )
    );

    ctx.state.data = {
        title: $('title').text(),
        link: currentUrl,
        item: items,
    };
};
