const got = require('@/utils/got');
const cheerio = require('cheerio');
const { parseDate } = require('@/utils/parse-date');

module.exports = async (ctx) => {
    const category = ctx.params.category ?? 'articles';
    const id = ctx.params.id ?? '';

    const rootUrl = 'https://www.storm.mg';
    const currentUrl = `${rootUrl}/${category}${id ? `/${id}` : ''}`;

    const response = await got({
        method: 'get',
        url: currentUrl,
    });

    const $ = cheerio.load(response.data);

    const list = $('.link_title')
        .map((_, item) => {
            item = $(item);

            return {
                title: item.text(),
                link: item.attr('href'),
            };
        })
        .get();

    const items = await Promise.all(
        list.map((item) =>
            ctx.cache.tryGet(item.link, async () => {
                const detailResponse = await got({
                    method: 'get',
                    url: item.link,
                });

                const content = cheerio.load(detailResponse.data);

                content('.notify_wordings').remove();
                content('#premium_block').remove();

                item.description = content('#CMS_wrapper').html();
                item.author = content('meta[property="dable:author"]').attr('content');
                item.pubDate = parseDate(content('meta[itemprop="datePublished"]').attr('content'));

                return item;
            })
        )
    );

    ctx.state.data = {
        title: $('title').text(),
        link: currentUrl,
        item: items,
    };
};
